<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# Node Version

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Node version.

<section class="installation">

## Installation

```bash
npm install @stdlib/process-node-version
```

</section>

<section class="usage">

## Usage

```javascript
var NODE_VERSION = require( '@stdlib/process-node-version' );
```

#### NODE_VERSION

Node version.

```javascript
console.log( NODE_VERSION );
// => <string>
```

</section>

<!-- /.usage -->

<section class="notes">

## Notes

-   In browser environments and environments other than Node.js the Node version is equal to `null`.

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var semver = require( 'semver' );
var NODE_VERSION = require( '@stdlib/process-node-version' );

if ( semver.lt( NODE_VERSION, '1.0.0' ) ) {
    console.log( 'Running on a pre-io.js version...' );
}
else if ( semver.lt( NODE_VERSION, '4.0.0' ) ) {
    console.log( 'Running on an io.js version...' );
}
else {
    console.log( 'Running on a post-io.js version...' );
}
```

</section>

<!-- /.examples -->



<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

## See Also

-   <span class="package-name">[`@stdlib/process-node-version-cli`][@stdlib/process-node-version-cli]</span><span class="delimiter">: </span><span class="description">CLI package for use as a command-line utility.</span>


</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2024. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[@stdlib/process-node-version-cli]: https://www.npmjs.com/package/@stdlib/process-node-version-cli

[npm-image]: http://img.shields.io/npm/v/@stdlib/process-node-version.svg
[npm-url]: https://npmjs.org/package/@stdlib/process-node-version

[test-image]: https://github.com/stdlib-js/process-node-version/actions/workflows/test.yml/badge.svg?branch=v0.2.2
[test-url]: https://github.com/stdlib-js/process-node-version/actions/workflows/test.yml?query=branch:v0.2.2

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/process-node-version/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/process-node-version?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/process-node-version.svg
[dependencies-url]: https://david-dm.org/stdlib-js/process-node-version/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[cli-section]: https://github.com/stdlib-js/process-node-version#cli
[cli-url]: https://github.com/stdlib-js/process-node-version/tree/cli
[@stdlib/process-node-version]: https://github.com/stdlib-js/process-node-version/tree/main

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/process-node-version/tree/deno
[deno-readme]: https://github.com/stdlib-js/process-node-version/blob/deno/README.md
[umd-url]: https://github.com/stdlib-js/process-node-version/tree/umd
[umd-readme]: https://github.com/stdlib-js/process-node-version/blob/umd/README.md
[esm-url]: https://github.com/stdlib-js/process-node-version/tree/esm
[esm-readme]: https://github.com/stdlib-js/process-node-version/blob/esm/README.md
[branches-url]: https://github.com/stdlib-js/process-node-version/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/process-node-version/main/LICENSE

</section>

<!-- /.links -->
